@@ -13,7 +13,7 @@ use 5.006;
 use Exporter;
 
 BEGIN {
-    $VERSION = '1.15';
+    $VERSION = '1.16';
     @EXPORT  = qw( Dump Load DumpFile LoadFile );
     @ISA     = qw( Exporter );
 
@@ -172,9 +172,9 @@ B<NOTE>: If you are working with other language's YAML/Syck bindings
 calling the C<Load>/C<Dump> functions.  The default setting is for
 preserving backward-compatibility with C<YAML.pm>.
 
-=head1 Differences Between Yaml::Syck and YAML
+=head1 Differences Between YAML::Syck and YAML
 
-head2 Error handling
+=head2 Error handling
 
 Some calls are designed to die rather than returning YAML. You should wrap
 your calls in eval to assure you do not get unexpected results.
